var path = require('path');
var fs = require('fs');
var express = require('express');
var bodyParser = require('body-parser');
var AWS = require('aws-sdk');

var server = express();
var polly = new AWS.Polly({apiVersion: '2016-06-10', region: 'ap-northeast-1'});

server.use(bodyParser.json());

server.use(express.static(path.join(__dirname, 'public')));

var mp3FilePath = path.join(__dirname, 'data', 'text.mp3');

server.post('/polly', function(req, res) {
  console.log(req.body);
  var text = req.body.text;
  var voiceid = req.body.voiceid;

  var speechParams = {
    OutputFormat: 'mp3',
    VoiceId: voiceid,
    Text: text,
    SampleRate: '22050',
    TextType: 'text'
  };

  polly.synthesizeSpeech(speechParams, function(err, data) {
    if (err) {
      console.log(err, err.stack);
      res.send( { status: "failure", message: err.message } );
    } else {
      console.log(data);
      fs.writeFile(mp3FilePath, data.AudioStream, function (err) {
        if (err) {
          console.log(err);
          res.send( { status: "failure" , message: err.message } );
        } else {
          console.log('success');
          res.send( { status: "success" } );
        }
      });
    }
  });
});

server.get('/sound', function(req, res) {
  try {
    var buf = fs.readFileSync(mp3FilePath);
    res.header('Content-Type', 'audio/mpeg').send(buf);
  } catch (e) {
    console.log(e);
    res.status(404).send('Sorry cant find that!');
  }
});

server.listen(8000, function() {
  console.log( 'Listening on port 8000' );
});
